/*
 * Tools for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.funcinfo;

import pl.chyla.wyjec.core.Type;


/**
 * Contains information about example Wyjec expression and the result of its evaluation
 * specified in string form together with its type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class ExpressionExample {

    /**
     * Example expression.
     */
    private final String expression;

    /**
     * Type of the result of the expression evaluation.
     */
    private final Type resultType;

    /**
     * Result of the expression evaluation in string form.
     */
    private final String resultString;

    /**
     * Constructs <code>ExpressionExample</code> instance with given expression and result
     * specified using its type and string form of its value.
     *
     * @param expression example expression
     * @param resultType type of the result of the expression evaluation
     * @param resultString the result of the expression evaluation in string form
     * @throws IllegalArgumentException
     *     in case given <code>expression</code>, <code>resultType</code> or
     *     <code>resultString</code> is <code>null</code>
     */
    public ExpressionExample(String expression, Type resultType, String resultString) {
        if (expression == null || resultType == null || resultString == null) {
            throw new IllegalArgumentException(
                "Expression, result type and result string must not be null");
        }
        this.expression = expression;
        this.resultType = resultType;
        this.resultString = resultString;
    }

    /**
     * Returns the example expression represented by this object.
     *
     * @return contained example expression in string form
     */
    public String getExpression() {
        return expression;
    }

    /**
     * Returns the result of evaluation of the example expression in string form.
     *
     * @return string form of the evaluation result
     */
    public String getResultString() {
        return resultString;
    }

    /**
     * Returns type of the result of evaluation of the example expression.
     *
     * @return type of the evaluation result
     */
    public Type getResultType() {
        return resultType;
    }

}
