/*
 * Tools for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.simulation;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.funcinfo.FunctionInformation;


/**
 * Interface used for evaluating simulated functions (implemented using
 * {@link SimulatedFunction} class). It's possible to use single implementation of the interface
 * for evaluating many functions, because evaluating method receives an object that identifies a
 * function to be evaluated.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public interface IFunctionHandler {

    /**
     * Called from {@link SimulatedFunction} to evaluate a function's result using its
     * description (given as {@link FunctionInformation}) and an array of parameters.
     *
     * @param funcInfo description of function that is to be evaluated
     * @param result {@link Value} instance to store the result in; this value has to be updated
     * @param params array of parameters of the function
     */
    void evaluateFunction(FunctionInformation funcInfo, Value result, Value[] params);

}
